==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ytbdatatypes/rev20160826/ytbdatatypes/Def4.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbdatatypes.rev20160826.ytbdatatypes;

import java.util.Objects;

/**
 * Represents the implementation of def4.
 */
public final class Def4 {

    private boolean empty;

    /**
     * Creates an instance of def4.
     */
    private Def4() {
    }

    /**
     * Creates an instance of empty.
     *
     * @param empty value of empty
     */
    public Def4(boolean empty) {
        this.empty = empty;
    }

    /**
     * Returns the object of def4 for type empty.
     *
     * @param value value of def4 for type empty
     * @return def4 for type empty
     */
    public static Def4 of(boolean value) {
        return new Def4(value);
    }

    /**
     * Returns the attribute empty.
     *
     * @return empty value of empty
     */
    public boolean empty() {
        return empty;
    }
    /**
     * Sets the attribute empty.
     *
     * @param empty value of empty
     */
    public void empty(boolean empty) {
        this.empty = empty;
    }

    @Override
    public int hashCode() {
        return Objects.hash(empty);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof Def4) {
            Def4 other = (Def4) obj;
            return
                Objects.equals(empty, other.empty);
        }
        return false;
    }

    @Override
    public String toString() {
        return empty ? "true" : "false";
    }
    /**
     * Returns the object of def4 fromString input String def4.
     *
     * @param valInString value of input String
     * @return def4
     */
    public static Def4 fromString(String valInString) {
        try {
            boolean tmpVal = Boolean.parseBoolean(valInString);
            return of(tmpVal);
        } catch (Exception e) {
            throw new IllegalArgumentException("not a valid input element");
        }
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbdatatypes/rev20160826/ytbdatatypes/Def4.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbdatatypes.rev20160826.ytbdatatypes;

import java.util.Objects;

/**
 * Represents the implementation of def4.
 */
public final class Def4 {

    private boolean empty;

    /**
     * Creates an instance of def4.
     */
    private Def4() {
    }

    /**
     * Creates an instance of empty.
     *
     * @param empty value of empty
     */
    public Def4(boolean empty) {
        this.empty = empty;
    }

    /**
     * Returns the object of def4 for type empty.
     *
     * @param value value of def4 for type empty
     * @return def4 for type empty
     */
    public static Def4 of(boolean value) {
        return new Def4(value);
    }

    /**
     * Returns the attribute empty.
     *
     * @return empty value of empty
     */
    public boolean empty() {
        return empty;
    }
    /**
     * Sets the attribute empty.
     *
     * @param empty value of empty
     */
    public void empty(boolean empty) {
        this.empty = empty;
    }

    @Override
    public int hashCode() {
        return Objects.hash(empty);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof Def4) {
            Def4 other = (Def4) obj;
            return
                Objects.deepEquals(empty, other.empty);
        }
        return false;
    }

    @Override
    public String toString() {
        return empty ? "true" : "false";
    }
    /**
     * Returns the object of def4 fromString input String def4.
     *
     * @param valInString value of input String
     * @return def4
     */
    public static Def4 fromString(String valInString) {
        try {
            boolean tmpVal = Boolean.parseBoolean(valInString);
            return of(tmpVal);
        } catch (Exception e) {
            throw new IllegalArgumentException("not a valid input element");
        }
    }
}
